Configuration Format
----------------------

The category configuration is simply a list of categories names. An example in
yaml format:

.. code-block:: yaml

    - name: pedestrian
    - name: rider
    - name: other person
    - name: car
    - name: bus
    - name: truck
    - name: train
    - name: trailer
    - name: other vehicle
    - name: motorcycle
    - name: bicycle
    - name: traffic sign
    - name: traffic light